summaryrefslogtreecommitdiff
path: root/ci.h
diff options
context:
space:
mode:
Diffstat (limited to 'ci.h')
-rw-r--r--ci.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ci.h b/ci.h
index 3db0340a..df2d1564 100644
--- a/ci.h
+++ b/ci.h
@@ -4,7 +4,7 @@
* See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: ci.h 4.13 2019/03/19 14:58:00 kls Exp $
+ * $Id: ci.h 4.14 2019/05/28 14:58:08 kls Exp $
*/
#ifndef __CI_H
@@ -331,9 +331,9 @@ public:
///< class function.
cDevice *Device(void) { return assignedDevice; }
///< Returns the device this CAM slot is currently assigned to.
- bool Devices(cVector<int> &CardIndexes);
- ///< Adds the card indexes of any devices that currently use this CAM to
- ///< the given CardIndexes. This can be more than one in case of MTD.
+ bool Devices(cVector<int> &DeviceNumbers);
+ ///< Adds the numbers of any devices that currently use this CAM to
+ ///< the given DeviceNumbers. This can be more than one in case of MTD.
///< Returns true if the array is not empty.
bool WantsTsData(void) const { return caPidReceiver != NULL; }
///< Returns true if this CAM slot wants to receive the TS data through